EventSinkTransformer<T, S> class abstract

Simple implementation of EventSink for transforming events.

Implemented types
Implementers

Constructors

EventSinkTransformer(EventSink<S> outputSink)
Creates an EventSinkTransformer with the given output sink.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
outputSink EventSink<S>
The output sink to which transformed events are added.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(T event) → void
Adds a data event to the sink.
override
addError(Object e, [StackTrace? st]) → void
Adds an error to the sink.
override
addToSink(S event) → void
Adds a transformed event to the output sink.
close() → void
Closes the sink.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited