SimpleStreamEventSinkTransformer<T, S> class

A simple implementation of StreamTransformerBase for event sinks.

Inheritance

Constructors

SimpleStreamEventSinkTransformer(EventSinkConstructor<S> eventSink)
Creates a SimpleStreamEventSinkTransformer with the given event sink constructor.
const
SimpleStreamEventSinkTransformer.fromSink(EventSinkConstructor<S> mapSink)
Factory constructor to create a transformer from a sink constructor.
factory

Properties

eventSink EventSinkConstructor<S>
The event sink constructor used for transformation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<T> stream) Stream<S>
Binds the transformer to the provided stream.
override
cast<RS, RT>() StreamTransformer<RS, RT>
Provides a StreamTransformer<RS, RT> view of this stream transformer.
inherited
mapSink(EventSink<S> sink) EventSink
Maps the provided sink using the event sink constructor.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited