SseByteStreamSplitterSink class final

SSE event byte stream splitter. Separates each event from multiple events.

For more information about the SSE protocol, refer to the documentation: https://html.spec.whatwg.org/multipage/server-sent-events.html

Inheritance

Constructors

SseByteStreamSplitterSink(EventSink<Iterable<int>> outputSink)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
outputSink EventSink<Iterable<int>>
The output sink to which transformed events are added.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(List<int> event) → void
Adds a splitted byte SSE event to the output sink.
override
addError(Object e, [StackTrace? st]) → void
Adds an error to the sink.
inherited
addToSink(Iterable<int> event) → void
Adds a transformed event to the output sink.
inherited
close() → void
Closes the sink.
inherited
filterBetweenSeparator(List<int> event) Iterable<List<int>>
Splits the input byte event into separate SSE events using the separator.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited